;;; 43

(define x 42)

(define (inc x)
  (+ x 1))

(trace (inc x))